document.addEventListener('DOMContentLoaded', () => {
  const textarea = document.querySelector('.writing-area');
  const wordCount = document.querySelector('.word-count span');
  let timeout = null;

  function countWords(text) {
    return text.trim().split(/\s+/).filter(word => word.length > 0).length;
  }

  function updateWordCount() {
    const count = countWords(textarea.value);
    wordCount.textContent = count;
  }

  function autoSave() {
    clearTimeout(timeout);
    timeout = setTimeout(() => {
      localStorage.setItem('zenwrite-content', textarea.value);
    }, 1000);
  }

  textarea.addEventListener('input', () => {
    updateWordCount();
    autoSave();
  });

  // Load saved content
  const savedContent = localStorage.getItem('zenwrite-content');
  if (savedContent) {
    textarea.value = savedContent;
    updateWordCount();
  }

  // Dark mode toggle
  const prefersDark = window.matchMedia('(prefers-color-scheme: dark)');
  function setColorScheme(e) {
    if (e.matches) {
      document.documentElement.style.setProperty('--bg-color', '#1a1a1a');
      document.documentElement.style.setProperty('--text-color', '#f0f0f0');
    } else {
      document.documentElement.style.setProperty('--bg-color', '#f9f9f9');
      document.documentElement.style.setProperty('--text-color', '#333');
    }
  }
  prefersDark.addListener(setColorScheme);
  setColorScheme(prefersDark);
});